==> qtify_0.0.1-4.tar.gz: qtify-0.0.1/translations/qtify_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>Playlist</source>
        <translation type="unfinished">Playlist</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Artist</source>
        <translation type="unfinished">Interpret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Album</source>
        <translation type="unfinished">Album</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Rating</source>
        <translation type="unfinished">Bewertung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Search</source>
        <translation type="unfinished">Suchen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Username</source>
        <translation type="unfinished">Benutzername</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Password</source>
        <translation type="unfinished">Passwort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Show</source>
        <translation type="unfinished">Anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <source>Title</source>
        <translation type="unfinished">Titel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="306"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Play/Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="57"/>
        <source>Incorrect credentials entered
please try again.</source>
        <translation type="unfinished">Falscher Benutzername oder Passwort. Bitte erneut versuchen.</translation>
    </message>
</context>
</TS>

==> qtify_0.0.2.tar.gz: qtify-0.0.2/translations/qtify_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Playlist</source>
        <translation type="unfinished">Playlist</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <source>Artist</source>
        <translation type="unfinished">Interpret</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Album</source>
        <translation type="unfinished">Album</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>Rating</source>
        <translation type="unfinished">Bewertung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>Search</source>
        <translation type="unfinished">Suchen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="144"/>
        <source>Username</source>
        <translation type="unfinished">Benutzername</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Password</source>
        <translation type="unfinished">Passwort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Show</source>
        <translation type="obsolete">Anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Title</source>
        <translation type="unfinished">Titel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>Incorrect credentials entered
please try again.</source>
        <translation type="unfinished">Falscher Benutzername oder Passwort. Bitte erneut versuchen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="70"/>
        <source>Authenticating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Updating playlists...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="112"/>
        <source>Select playlist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
